@@ -42,7 +42,7 @@ def id(id: str):
     return _defineProp(fn)
 
 
-class groupId(SeriesProp):
+class dataGroupId(SeriesProp):
     """"""
 
     def __init__(self, id) -> None:
@@ -50,7 +50,7 @@ class groupId(SeriesProp):
         super().__init__()
 
         def fn(series_obj):
-            series_obj["groupId"] = id
+            series_obj["dataGroupId"] = id
             return series_obj
 
         self._add_fns(fn)
